rtmidi package
==============

Submodules
----------

rtmidi.midiconstants module
---------------------------

.. automodule:: rtmidi.midiconstants
   :members:
   :undoc-members:
   :show-inheritance:

rtmidi.midiutil module
----------------------

.. automodule:: rtmidi.midiutil
   :members:
   :undoc-members:
   :show-inheritance:

rtmidi.version module
---------------------

.. automodule:: rtmidi.version
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: rtmidi
   :members:
   :undoc-members:
   :show-inheritance:

Functions
~~~~~~~~~

.. autofunction:: get_api_name

.. autofunction:: get_api_display_name

.. autofunction:: get_compiled_api

.. autofunction:: get_compiled_api_by_name

.. autofunction:: get_rtmidi_version


Exceptions
~~~~~~~~~~

.. autoclass:: rtmidi.RtMidiError
   :members:

.. autoclass:: rtmidi.InvalidPortError
   :members:

.. autoclass:: rtmidi.InvalidUseError
   :members:

.. autoclass:: rtmidi.MemoryAllocationError
   :members:

.. autoclass:: rtmidi.NoDevicesError
   :members:

.. autoclass:: rtmidi.SystemError
   :members:

.. autoclass:: rtmidi.UnsupportedOperationError
   :members:


Classes
~~~~~~~


.. autoclass:: rtmidi.MidiIn
   :members:
   :inherited-members:

.. autoclass:: rtmidi.MidiOut
   :members:
   :inherited-members:
